==> haskell-vty-5.25.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.25.1
id: vty-5.25.1-Gwpkn0eD7RDB852iBG2MsU
key: vty-5.25.1-Gwpkn0eD7RDB852iBG2MsU
license: BSD-3-Clause
maintainer: Jonathan Daugherty (cygnus@foobox.com)
author: AUTHORS
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
abi: 5e91ee35786ee4334366dd57d4e3b711
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs: /usr/lib/ghc-8.6.5/site-local/vty-5.25.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/vty-5.25.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vty-5.25.1
hs-libraries: HSvty-5.25.1-Gwpkn0eD7RDB852iBG2MsU
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.11.1-5dh821ORebgAorhvJor7TN
    microlens-mtl-0.2.0.1-E4YQOt1SovZ6XqAZ7j7hTE
    microlens-th-0.4.3.1-AUW9LaqhPnN9WhzH0kkXqs mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ parsec-3.1.13.0 stm-2.5.0.0
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.6.2 unix-2.7.2.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-5.25.1-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.25.1
id: vty-5.25.1-7HOoryGNetBKpCZF0x8Xt0
key: vty-5.25.1-7HOoryGNetBKpCZF0x8Xt0
license: BSD-3-Clause
maintainer: Jonathan Daugherty (cygnus@foobox.com)
author: AUTHORS
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
abi: 0796738cd7bdffffceb3f7d5b03367ee
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs: /usr/lib/ghc-8.6.5/site-local/vty-5.25.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/vty-5.25.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vty-5.25.1
hs-libraries: HSvty-5.25.1-7HOoryGNetBKpCZF0x8Xt0
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-LqA2iMwHon3GVoHwu983SC mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ parsec-3.1.13.0 stm-2.5.0.0
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.6.2 unix-2.7.2.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
